@@ -95,15 +95,6 @@ public:
          */
         virtual void activating(MappedRegistry *user);
 
-        /**
-         * Resolve remote uri's.
-         * @param host of remote server.
-         * @param port of remote server (0 = unspecified/srv).
-         * @param addr buffer to use.
-         * @return schema assocated with uri, or NULL if not found.
-         */
-        virtual const char *resolve(const char *uri , struct sockaddr_storage *addr);
-
         /**
          * Notify plugins a user registration has been expired or released.
          * @param user registration that was expired.
