@@ -52,8 +52,6 @@ class __EXPORT uri
 {
 public:
     static voip::context_t route(const char *uri, char *buf, size_t size);
-    static bool resolve(const char *sipuri, char *buffer, size_t size);
-    static bool rewrite(const char *sipuri, char *buffer, size_t size);
     static void serviceid(const char *sipuri, char *buffer, size_t size);
     static bool server(struct sockaddr *address, char *buffer, size_t size);
     static bool userid(const char *sipuri, char *buffer, size_t size);
@@ -81,8 +79,13 @@ protected:
 
 public:
     srv(const char *uri);
+    srv();
     ~srv();
 
+    void set(const char *uri);
+
+    void clear(void);
+
     inline struct sockaddr *operator*() const
 	    {return entry;};
 
@@ -94,7 +97,7 @@ public:
 
     struct sockaddr *next(void);
 
-    static voip::context_t route(struct sockaddr_storage *addr, const char *uri, char *buf, size_t size);
+    voip::context_t route(const char *uri, char *buf, size_t size);
 
 };
 
